==> blesta-5.10.2.zip: blesta/plugins/system_overview/language/pl_pl/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.new'] = 'Nowość';
$lang['AdminMain.graph_line_name.suspended'] = 'Zawieszony';
$lang['AdminMain.graph_line_name.canceled'] = 'Anulowane';
$lang['AdminMain.graph_line_name.active'] = 'Aktywny';
$lang['AdminMain.graph_name.graph_clients'] = 'Klienci';
$lang['AdminMain.graph_name.graph_services'] = 'Usługi';
$lang['AdminMain.settings.submit_settings'] = 'Ustawienia aktualizacji';
$lang['AdminMain.settings.submit_cancel'] = 'Powrót do przeglądu';
$lang['AdminMain.settings.date_range'] = 'Zakres dat wykresu';
$lang['AdminMain.settings.show_legend'] = 'Pokaż legendę';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Wykresy nie są już rozdzielane w kartach, lecz wyświetlane w jednej karcie.';
$lang['AdminMain.settings.show_one_tab'] = 'Pokaż tylko jedną kartę';
$lang['AdminMain.settings.heading_settings'] = 'Ustawienia';
$lang['AdminMain.settings.graph_services'] = 'Wykres usług';
$lang['AdminMain.settings.text_graphs_services'] = 'Sprawdź, które wykresy powinny pojawić się na karcie Usługi.';
$lang['AdminMain.settings.heading_services'] = 'Zakładka Usługi';
$lang['AdminMain.settings.graph_clients'] = 'Wykres klientów';
$lang['AdminMain.settings.text_graphs_clients'] = 'Sprawdź, które wykresy powinny pojawić się na karcie Klienci.';
$lang['AdminMain.settings.heading_clients'] = 'Zakładka Klienci';
$lang['AdminMain.settings.pending_orders'] = 'Zamówienia oczekujące';
$lang['AdminMain.settings.open_tickets'] = 'Otwarte bilety';
$lang['AdminMain.settings.recurring_invoices'] = 'Faktury cykliczne';
$lang['AdminMain.settings.active_users_today'] = 'Użytkownicy aktywni dzisiaj';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Usługi zaplanowane do anulowania';
$lang['AdminMain.settings.services_active'] = 'Aktywne usługi';
$lang['AdminMain.settings.clients_active'] = 'Aktywni klienci';
$lang['AdminMain.settings.text_options'] = 'Sprawdź opcje, które pojawią się w przeglądzie systemu.';
$lang['AdminMain.settings.heading_statistics'] = 'Statystyki';
$lang['AdminMain.date_range.days'] = '%1$s dni';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minut temu';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minutę temu';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Właśnie teraz';
$lang['AdminMain.overview.tooltip_location'] = 'Lokalizacja';
$lang['AdminMain.overview.tooltip_activity'] = 'Ostatnia aktywność';
$lang['AdminMain.overview.tab_services'] = 'Usługi';
$lang['AdminMain.overview.tab_clients'] = 'Klienci';
$lang['AdminMain.overview.tab_all'] = 'Wykresy';
$lang['AdminMain.overview.heading_users'] = 'Ostatni użytkownicy';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Otwarte bilety';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Zamówienia oczekujące';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Faktury cykliczne';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Użytkownicy aktywni dzisiaj';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Usługi zaplanowane do anulowania';
$lang['AdminMain.overview.statistic.services_active'] = 'Aktywne usługi';
$lang['AdminMain.overview.statistic.clients_active'] = 'Aktywni klienci';
$lang['AdminMain.index.boxtitle_overview'] = 'Przegląd systemu';
$lang['AdminMain.!success.options_updated'] = 'Ustawienia Przeglądu systemu zostały pomyślnie zaktualizowane!';

==> blesta-5.11.4.zip: blesta/plugins/system_overview/language/pl_pl/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.new'] = 'Nowość';
$lang['AdminMain.graph_line_name.suspended'] = 'Zawieszony';
$lang['AdminMain.graph_line_name.canceled'] = 'Anulowane';
$lang['AdminMain.graph_line_name.active'] = 'Aktywny';
$lang['AdminMain.graph_name.graph_clients'] = 'Klienci';
$lang['AdminMain.graph_name.graph_services'] = 'Usługi';
$lang['AdminMain.settings.submit_settings'] = 'Ustawienia aktualizacji';
$lang['AdminMain.settings.submit_cancel'] = 'Powrót do przeglądu';
$lang['AdminMain.settings.date_range'] = 'Zakres dat wykresu';
$lang['AdminMain.settings.show_legend'] = 'Pokaż legendę';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Wykresy nie są już rozdzielane w kartach, lecz wyświetlane w jednej karcie.';
$lang['AdminMain.settings.show_one_tab'] = 'Pokaż tylko jedną kartę';
$lang['AdminMain.settings.heading_settings'] = 'Ustawienia';
$lang['AdminMain.settings.graph_services'] = 'Wykres usług';
$lang['AdminMain.settings.text_graphs_services'] = 'Sprawdź, które wykresy powinny pojawić się na karcie Usługi.';
$lang['AdminMain.settings.heading_services'] = 'Zakładka Usługi';
$lang['AdminMain.settings.graph_clients'] = 'Wykres klientów';
$lang['AdminMain.settings.text_graphs_clients'] = 'Sprawdź, które wykresy powinny pojawić się na karcie Klienci.';
$lang['AdminMain.settings.heading_clients'] = 'Zakładka Klienci';
$lang['AdminMain.settings.pending_orders'] = 'Zamówienia oczekujące';
$lang['AdminMain.settings.open_tickets'] = 'Otwarte bilety';
$lang['AdminMain.settings.recurring_invoices'] = 'Faktury cykliczne';
$lang['AdminMain.settings.active_users_today'] = 'Użytkownicy aktywni dzisiaj';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Usługi zaplanowane do anulowania';
$lang['AdminMain.settings.services_active'] = 'Aktywne usługi';
$lang['AdminMain.settings.clients_active'] = 'Aktywni klienci';
$lang['AdminMain.settings.text_options'] = 'Sprawdź opcje, które pojawią się w przeglądzie systemu.';
$lang['AdminMain.settings.heading_statistics'] = 'Statystyki';
$lang['AdminMain.date_range.days'] = '%1$s dni';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minut temu';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minutę temu';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Właśnie teraz';
$lang['AdminMain.overview.tooltip_location'] = 'Lokalizacja';
$lang['AdminMain.overview.tooltip_activity'] = 'Ostatnia aktywność';
$lang['AdminMain.overview.tab_services'] = 'Usługi';
$lang['AdminMain.overview.tab_clients'] = 'Klienci';
$lang['AdminMain.overview.tab_all'] = 'Wykresy';
$lang['AdminMain.overview.heading_users'] = 'Ostatni użytkownicy';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Otwarte bilety';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Zamówienia oczekujące';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Faktury cykliczne';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Użytkownicy aktywni dzisiaj';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Usługi zaplanowane do anulowania';
$lang['AdminMain.overview.statistic.services_active'] = 'Aktywne usługi';
$lang['AdminMain.overview.statistic.clients_active'] = 'Aktywni klienci';
$lang['AdminMain.index.boxtitle_overview'] = 'Przegląd systemu';
$lang['AdminMain.!success.options_updated'] = 'Ustawienia Przeglądu systemu zostały pomyślnie zaktualizowane!';
$lang['AdminMain.date_range.day'] = '1 Dzień';
$lang['AdminMain.date_range.month'] = 'Bieżący miesiąc';
$lang['AdminMain.date_range.ytd'] = 'Od początku roku';
